@@ -423,5 +423,22 @@ test_that('SimDesign', {
     expect_true('thatfile.rds' %in% dir())
     SimClean('thatfile.rds')
 
+    results <- runSimulation(Design, replications = 10, save=TRUE, save_details = list(tmpfilename = 'thisfile', out_rootdir = "~/mytmpdir"),
+                             generate=Generate, analyse=Analyse2, summarise=Summarise, filename = 'thatfile',
+                             verbose=FALSE)
+    expect_true('thatfile.rds' %in% dir("~/mytmpdir"))
+    SimClean('thatfile.rds', save_details = list(out_rootdir = "~/mytmpdir"))
+    expect_false('thatfile.rds' %in% dir("~/mytmpdir"))
+
+    gen_anal <- function(condition, dat, fixed_objects = NULL){
+        dat <- rnorm(100)
+        mean(dat)
+    }
+    Summarise <- function(condition, results, fixed_objects = NULL)
+        bias(results, 0)
+    results <- runSimulation(replications = 10, analyse=gen_anal,
+                             summarise=Summarise)
+    expect_is(results, 'SimDesign')
+
 })
 
